(function() {var implementors = {};
implementors["std"] = [{"text":"impl&lt;F:&nbsp;<a class=\"trait\" href=\"std/future/trait.Future.html\" title=\"trait std::future::Future\">Future</a>&gt; <a class=\"trait\" href=\"std/future/trait.Future.html\" title=\"trait std::future::Future\">Future</a> for <a class=\"struct\" href=\"std/panic/struct.AssertUnwindSafe.html\" title=\"struct std::panic::AssertUnwindSafe\">AssertUnwindSafe</a>&lt;F&gt;","synthetic":false,"types":["std::panic::AssertUnwindSafe"]}];
if (window.register_implementors) {window.register_implementors(implementors);} else {window.pending_implementors = implementors;}})()